@@ -2,9 +2,11 @@ package Proc::Guard;
 use strict;
 use warnings;
 use 5.00800;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 use Carp ();
 
+our $EXIT_STATUS;
+
 # functional interface
 our @EXPORT = qw/proc_guard/;
 use Exporter 'import';
@@ -20,8 +22,9 @@ sub proc_guard {
 
 # OOish interface
 use POSIX;
-use Class::Accessor::Lite;
-Class::Accessor::Lite->mk_accessors(qw/pid/);
+use Class::Accessor::Lite 0.05 (
+	rw => ['pid'],
+);
 
 sub new {
     my $class = shift;
@@ -71,13 +74,17 @@ sub stop {
 
     kill $sig, $self->pid;
     1 while waitpid( $self->pid, 0 ) <= 0;
+    $EXIT_STATUS = $?;
 
     $self->pid(undef);
 }
 
 sub DESTROY {
     my $self = shift;
-    $self->stop() if defined $self->pid && $$ == $self->{_owner_pid};
+    if (defined $self->pid && $$ == $self->{_owner_pid}) {
+        local $?; # "END" function and destructors can change the exit status by modifying $?.(perldoc -f exit)
+        $self->stop()
+    }
 }
 
 1;
@@ -180,6 +187,16 @@ Stops process.
 
 =back
 
+=head1 VARIABLES
+
+=over 4
+
+=item $Proc::Guard::EXIT_STATUS
+
+The last exit status code by C<< $proc->stop >>.
+
+=back
+
 =head1 AUTHOR
 
 Tokuhiro Matsuno E<lt>tokuhirom AAJKLFJEF GMAIL COME<gt>
